==> spip_2.0.8.orig.tar.gz: spip-2.0.8.orig/ecrire/lang/public_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Beginpagina',
'articles' => 'Artikels',
'articles_auteur' => 'Artikels van deze auteur',
'articles_populaires' => 'Meest bekeken artikels',
'articles_rubrique' => 'Artikels van deze rubriek',
'aucun_article' => 'Op dit adres is geen artikel te vinden',
'aucun_auteur' => 'Op dit adres is geen auteur te vinden',
'aucun_site' => 'Op dit adres is geen site te vinden',
'aucune_breve' => 'Op dit adres is geen nieuwsbericht te vinden',
'aucune_rubrique' => 'Op dit adres is geen rubriek te vinden',
'autres' => 'Anderen',
'autres_breves' => 'Andere nieuwsberichten',
'autres_groupes_mots_clefs' => 'Andere groepen trefwoorden',
'autres_sites' => 'Andere sites',

// B
'bonjour' => 'Hallo',
'breves' => 'Nieuwsberichten',

// C
'commenter_site' => 'Commentaar geven op de site',
'copie_document_impossible' => 'Onmogelijk om het document te kopi&euml;ren',

// D
'date' => 'Datum',
'dernier_ajout' => 'Laatste toevoeging',
'dernieres_breves' => 'Laatste nieuwsberichten',
'derniers_articles' => 'Laatste artikels',
'derniers_commentaires' => 'Laatste commentaren',
'derniers_messages_forum' => 'Laatst gepubliceerde berichten in het forum',
'documents_interdits_forum' => 'Verboden documenten in het forum',

// E
'edition_mode_texte' => 'Uitgave in tekstmodus van',
'en_reponse' => 'Als antwoord op&nbsp;:',
'en_resume' => 'Samengevat',
'envoyer_message' => 'Een bericht sturen',
'espace_prive' => 'Priv&eacute;-site',

// F
'formats_acceptes' => 'Aanvaarde formaten : @formats@.',
'forum' => 'Forum',

// H
'hierarchie_site' => 'Structuur van de site',

// J
'jours' => 'dagen',

// L
'lien_connecter' => 'Zich aansluiten',

// M
'meme_auteur' => 'Van dezelfde auteur',
'meme_rubrique' => 'In dezelfde rubriek',
'memes_auteurs' => 'Van dezelfde auteurs',
'message' => 'Bericht',
'messages_forum' => 'Berichten van het forum',
'messages_recents' => 'Meest recente berichten van de forums',
'mots_clefs' => 'Trefwoorden',
'mots_clefs_meme_groupe' => 'Trefwoorden van dezelfde groep',

// N
'navigation' => 'Navigatie',
'nom' => 'Naam',
'nouveautes' => 'Nieuwigheden',
'nouveautes_web' => 'Nieuwigheden op het Web',
'nouveaux_articles' => 'Nieuwe artikels',
'nouvelles_breves' => 'Nieuwe nieuwsberichten',

// P
'page_precedente' => 'vorige pagina',
'page_suivante' => 'volgende pagina',
'par_auteur' => 'door ',
'participer_site' => 'Je kan bijdragen tot deze site door je eigen artikels voor te stellen als je je hieronder inschrijft. Je krijgt meteen een e-mail met daarin de toegangscode voor de priv&eacute;-deel van de site.',
'plan_site' => 'Overzicht van de site',
'popularite' => 'Populariteit',
'poster_message' => 'Een bericht plaatsen',
'proposer_site' => 'Je kan voorstellen een site in deze rubriek op te nemen&nbsp;:',

// R
'repondre_article' => 'Dit artikel beantwoorden',
'repondre_breve' => 'Dit nieuwsbericht beantwoorden',
'repondre_message' => 'Dit bericht beantwoorden',
'resultats_recherche' => 'Resultaten van de zoekopdracht',
'retour_debut_forums' => 'Terug naar de startpagina van de forums',
'rubrique' => 'Rubriek',
'rubriques' => 'Rubrieken',

// S
'signatures_petition' => 'Ondertekeningen',
'site_realise_avec_spip' => 'Site gebouwd met SPIP',
'sites_web' => 'Websites',
'sous_rubriques' => 'Subrubrieken',
'spam' => 'Spam',
'suite' => 'vervolg',
'sur_web' => 'Op het web',
'syndiquer_rubrique' => 'Nieuws overnemen uit deze rubriek',
'syndiquer_site' => 'Nieuws overnemen van de hele site',

// T
'texte_lettre_information' => 'Ziehier de nieuwsbrief van de site',
'texte_lettre_information_2' => 'De nieuwsbrief vermedlt alle artikels en berichten gepubliceerd sinds',

// V
'ver_imprimer' => 'Afdrukversie',
'voir_en_ligne' => 'Online bekijken',
'voir_squelette' => 'het skelet van deze bladzijde zien'
);

?>

==> spip_2.1.1.orig.tar.gz: spip-2.1.1/ecrire/lang/public_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Beginpagina',
'article' => 'Article', # NEW
'articles' => 'Artikels',
'articles_auteur' => 'Artikels van deze auteur',
'articles_populaires' => 'Meest bekeken artikels',
'articles_rubrique' => 'Artikels van deze rubriek',
'aucun_article' => 'Op dit adres is geen artikel te vinden',
'aucun_auteur' => 'Op dit adres is geen auteur te vinden',
'aucun_site' => 'Op dit adres is geen site te vinden',
'aucune_breve' => 'Op dit adres is geen nieuwsbericht te vinden',
'aucune_rubrique' => 'Op dit adres is geen rubriek te vinden',
'auteur' => 'Auteur', # NEW
'autres' => 'Anderen',
'autres_breves' => 'Andere nieuwsberichten',
'autres_groupes_mots_clefs' => 'Andere groepen trefwoorden',
'autres_sites' => 'Andere sites',

// B
'bonjour' => 'Hallo',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Nieuwsberichten',

// C
'commenter_site' => 'Commentaar geven op de site',
'copie_document_impossible' => 'Onmogelijk om het document te kopi&euml;ren',

// D
'date' => 'Datum',
'dernier_ajout' => 'Laatste toevoeging',
'dernieres_breves' => 'Laatste nieuwsberichten',
'derniers_articles' => 'Laatste artikels',
'derniers_commentaires' => 'Laatste commentaren',
'derniers_messages_forum' => 'Laatst gepubliceerde berichten in het forum',
'documents_interdits_forum' => 'Verboden documenten in het forum',

// E
'edition_mode_texte' => 'Uitgave in tekstmodus van',
'en_reponse' => 'Als antwoord op&nbsp;:',
'en_resume' => 'Samengevat',
'envoyer_message' => 'Een bericht sturen',
'espace_prive' => 'Priv&eacute;-site',

// F
'formats_acceptes' => 'Aanvaarde formaten : @formats@.',
'forum' => 'Forum',

// H
'hierarchie_site' => 'Structuur van de site',

// J
'jours' => 'dagen',

// L
'lien_connecter' => 'Zich aansluiten',

// M
'meme_auteur' => 'Van dezelfde auteur',
'meme_rubrique' => 'In dezelfde rubriek',
'memes_auteurs' => 'Van dezelfde auteurs',
'message' => 'Bericht',
'messages_forum' => 'Berichten van het forum',
'messages_recents' => 'Meest recente berichten van de forums',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Trefwoorden',
'mots_clefs_meme_groupe' => 'Trefwoorden van dezelfde groep',

// N
'navigation' => 'Navigatie',
'nom' => 'Naam',
'nouveautes' => 'Nieuwigheden',
'nouveautes_web' => 'Nieuwigheden op het Web',
'nouveaux_articles' => 'Nieuwe artikels',
'nouvelles_breves' => 'Nieuwe nieuwsberichten',

// P
'page_precedente' => 'vorige pagina',
'page_suivante' => 'volgende pagina',
'par_auteur' => 'door ',
'participer_site' => 'Je kan bijdragen tot deze site door je eigen artikels voor te stellen als je je hieronder inschrijft. Je krijgt meteen een e-mail met daarin de toegangscode voor de priv&eacute;-deel van de site.',
'plan_site' => 'Overzicht van de site',
'popularite' => 'Populariteit',
'poster_message' => 'Een bericht plaatsen',
'proposer_site' => 'Je kan voorstellen een site in deze rubriek op te nemen&nbsp;:',

// R
'repondre_article' => 'Dit artikel beantwoorden',
'repondre_breve' => 'Dit nieuwsbericht beantwoorden',
'repondre_message' => 'Dit bericht beantwoorden',
'resultats_recherche' => 'Resultaten van de zoekopdracht',
'retour_debut_forums' => 'Terug naar de startpagina van de forums',
'rubrique' => 'Rubriek',
'rubriques' => 'Rubrieken',

// S
'signatures_petition' => 'Ondertekeningen',
'site_realise_avec_spip' => 'Site gebouwd met SPIP',
'sites_web' => 'Websites',
'sous_rubriques' => 'Subrubrieken',
'spam' => 'Spam',
'suite' => 'vervolg',
'sur_web' => 'Op het web',
'syndiquer_rubrique' => 'Nieuws overnemen uit deze rubriek',
'syndiquer_site' => 'Nieuws overnemen van de hele site',

// T
'texte_lettre_information' => 'Ziehier de nieuwsbrief van de site',
'texte_lettre_information_2' => 'De nieuwsbrief vermedlt alle artikels en berichten gepubliceerd sinds',

// V
'ver_imprimer' => 'Afdrukversie',
'voir_en_ligne' => 'Online bekijken',
'voir_squelette' => 'het skelet van deze bladzijde zien'
);

?>
